Name:          rrd4j
Version:       2.2.1
Release:       1%{?dist}
Summary:       A high performance data logging and graphing system for time series data
License:       ASL 2.0
URL:           https://github.com/rrd4j/rrd4j
Source0:       https://github.com/rrd4j/rrd4j/archive/%{version}.tar.gz
Source1:       rrd4j.png
Source2:       rrd4j-inspector.appdata.xml

Patch0:        rrd4j-2.2.1-use-system-fonts.patch

BuildRequires: desktop-file-utils
BuildRequires: ImageMagick
BuildRequires: libappstream-glib
BuildRequires: maven-local
BuildRequires: mvn(com.sleepycat:je)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.mongodb:mongo-java-driver:2)
BuildRequires: mvn(org.sonatype.oss:oss-parent:pom:)
BuildRequires: dejavu-sans-mono-fonts
Requires:      dejavu-sans-mono-fonts
Requires:      %{name}-lib = %{version}-%{release}
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
BuildArch:     noarch

%description
RRD4J is a high performance data logging and graphing system
for time series data, implementing RRDTool's functionality
in Java. It follows much of the same logic and uses the
same data sources, archive types and definitions as RRDTool does.

RRD4J supports all standard operations on Round Robin Database
(RRD) files: CREATE, UPDATE, FETCH, LAST, DUMP, EXPORT and GRAPH.
RRD4J's API is made for those who are familiar with
RRDTool's concepts and logic, but prefer to work with pure Java
(no native functions or libraries, no Runtime.exec(), RRDTool
does not have to be present). 

%package lib
Summary:       RRD4J JAR artifacts

%description lib
This package contains RRD4J JAR artifacts.

%package demo
Summary:       Examples for %{name}
Requires:      %{name}-lib = %{version}-%{release}

%description demo
This package contains examples for %{name}.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{version}
find -name "*.class" -print -delete
find -name "*.jar" -print -delete
find -name "*.js" -print -delete

find -name "*.ttf" -print -delete
%patch0 -p1

%pom_change_dep :mongo-java-driver ::2

%pom_remove_plugin :maven-source-plugin
%pom_xpath_remove "pom:plugin[pom:artifactId = 'maven-javadoc-plugin']/pom:executions"

# Remove Class-Path
%pom_xpath_remove pom:manifestEntries

# Use java.awt.headless true
rm -r src/test/java/org/rrd4j/graph/*.java \
 src/test/java/org/rrd4j/core/RrdNioBackendTest.java
# java.net.UnknownHostException: oss.oetiker.ch
rm -r src/test/java/org/rrd4j/core/RrdDbTest.java
# AssertionError: failure in sub thread expected:<12> but was:<11>
rm -r src/test/java/org/rrd4j/core/RrdDbPoolTest.java

sed -i 's/\r//' LICENSE.txt

%mvn_package org.%{name}:%{name}::converter:
%mvn_package org.%{name}:%{name}::inspector:
%mvn_package org.%{name}:%{name}::demo: %{name}-demo

%build

%mvn_build

%install
%mvn_install

%jpackage_script org.rrd4j.converter.Converter "" "" %{name}/%{name}:%{name}/%{name}-converter %{name}-converter true
%jpackage_script org.rrd4j.inspector.RrdInspector "" "" %{name}/%{name}:%{name}/%{name}-inspector %{name}-inspector true

for p in 48 64 72 96 128; do
 mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${p}x${p}/apps
 convert %{SOURCE1} -fuzz 20% \
  -transparent white -geometry ${p}x${p} %{name}-inspector-${p}.png 
 cp -p %{name}-inspector-${p}.png %{buildroot}%{_datadir}/icons/hicolor/${p}x${p}/apps/%{name}-inspector.png
done
 
cat > %{name}-inspector.desktop << EOF
[Desktop Entry]
Name=RRD4J Inspector
GenericName=RRD4J Inspector
Comment=Utility to analyze, change and plot content of RRD files
Exec=%{name}-inspector
Icon=%{name}-inspector
Terminal=false
Type=Application
Categories=Development;
EOF

desktop-file-install --vendor="" --dir=%{buildroot}%{_datadir}/applications %{name}-inspector.desktop

mkdir -p %{buildroot}%{_datadir}/appdata
install -pm 644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}-inspector.appdata.xml
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/%{name}-inspector.appdata.xml

%post
/usr/bin/update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/usr/bin/update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%{_bindir}/%{name}-*
%{_datadir}/icons/hicolor/*/apps/%{name}-inspector.png
%{_datadir}/applications/%{name}-inspector.desktop
%{_datadir}/appdata/%{name}-inspector.appdata.xml
%doc README.md
%license LICENSE.txt

%files lib -f .mfiles
%doc changelog.txt
%license LICENSE.txt

%files demo -f .mfiles-%{name}-demo
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Sat Jul 11 2015 gil cattaneo <puntogil@libero.it> 2.2.1-1
- update to 2.2.1

* Thu Feb 26 2015 gil cattaneo <puntogil@libero.it> 2.2-1
- initial rpm
